# pydantic-bigstitcher

[![PyPI - Version](https://img.shields.io/pypi/v/pydantic-bigstitcher.svg)](https://pypi.org/project/pydantic-bigstitcher)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pydantic-bigstitcher.svg)](https://pypi.org/project/pydantic-bigstitcher)

-----

Pydantic models for [bigsticher](https://github.com/PreibischLab/BigStitcher). This is very minimal right now, with features being added only as needed.

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install pydantic-bigstitcher
```

## License

`pydantic-bigstitcher` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
